% A template for vfastcs submissions.
%
% adapted from elife template, v1.4
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{vfastcs}[2017/08/10, v0.5...]

\RequirePackage[english]{babel}

\RequirePackage{calc}
\RequirePackage{etoolbox}
\RequirePackage{regexpatch}
\RequirePackage{ifxetex,ifluatex}

\newif\ifxetexorluatex
\ifxetex
  \xetexorluatextrue
\else
  \ifluatex
    \xetexorluatextrue
  \else
    \xetexorluatexfalse
  \fi
\fi

\newif\if@reqslineno
\DeclareOption{lineno}{\@reqslinenotrue}

%% the type of document this is.  The current types:
% bestpractices, editorial, tutorial, training, review, software, lessons
\newif\if@bestpractices
\DeclareOption{bestpractices}{\@bestpracticestrue}

\newif\if@editorial
\DeclareOption{editorial}{\@editorialtrue}

\newif\if@tutorial
\DeclareOption{tutorial}{\@tutorialtrue}

\newif\if@training
\DeclareOption{training}{\@trainingtrue}

\newif\if@review
\DeclareOption{review}{\@reviewtrue}

\newif\if@software
\DeclareOption{software}{\@softwaretrue}

\newif\if@lessons
\DeclareOption{lessons}{\@lessonstrue}

%Publication Information
\newif\if@pubversion
\DeclareOption{pubversion}{\@pubversiontrue}

%% Linespacing.
\newif\if@onehalfspacing
\newif\if@doublespacing
\DeclareOption{onehalfspacing}{\@onehalfspacingtrue}
\DeclareOption{doublespacing}{\@doublespacingtrue}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{extarticle}}
\ExecuteOptions{}
\ProcessOptions\relax
\LoadClass{extarticle}

\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{mdframed}

\RequirePackage{lineno}
\if@reqslineno\linenumbers\fi

\ifxetexorluatex
\RequirePackage{fontspec}
\setmainfont[Ligatures = TeX,
  Extension = .ttf,
  UprightFont = *-Regular,
  BoldFont = *-Bold,
  ItalicFont = *-Italic,
  BoldItalicFont = *-BoldItalic]
  {Times New Roman}{14pt}
\else
  \RequirePackage[T1]{fontenc}
  \RequirePackage[utf8]{inputenc}
  \RequirePackage[default]{opensans}
  \renewcommand{\ttdefault}{lmtt}
\fi

\RequirePackage{microtype}

% Trueno/Open Sans requires a bigger "single" linespread.
\linespread{1.2}
\if@onehalfspacing\linespread{1.5}\fi
\if@doublespacing\linespread{2.0}\fi

\emergencystretch 3em

\RequirePackage{graphicx,xcolor}
\RequirePackage{graphicx}
\definecolor{vfastcsLightGray}{HTML}{F0F0F0}
\definecolor{vfastcsLightBlue}{HTML}{0A9DD9}
\definecolor{vfastcsMediumGrey}{HTML}{6D6E70}
\definecolor{vfastcsLightGrey}{HTML}{929497}
\definecolor{vfastcsMidnightBlue}{HTML}{191970}
\definecolor{vfastcsBlack}{HTML}{000000}


\RequirePackage{booktabs}
\RequirePackage{authblk}


\RequirePackage[%left=6cm,%
                %marginparwidth=4cm,%
                %marginparsep=0.5cm,%
                left=2cm,
                right=1.3cm,%
                top=3cm,%
                bottom=2.5cm,%
                headheight=21pt,%
                headsep=2\baselineskip,%
                columnsep=2em,%
                letterpaper]{geometry}%
%%%%%logo%%

\RequirePackage{tikz}
\newcommand{\journallogo}{%
  \begin{tikzpicture}[remember picture,overlay]
    \node[shift={(10 cm,-5cm)}] {\includegraphics[width=32 cm, height=18cm]{logo.pdf}};
  \end{tikzpicture}%
}



%%%%
                
\RequirePackage{changepage}

\RequirePackage{silence}
\WarningFilter{caption}{The option `hypcap=true' will be ignored}
\WarningFilter{microtype}{Unknown slot}

\RequirePackage[labelfont={bf},%
                labelsep=period,%
                justification=justified,%
                singlelinecheck=false,%
                tableposition=top,font=small]
                {caption}

% \captionsetup*[table]{skip=\medskipamount}


\RequirePackage[square,numbers,sort&compress]{natbib}
\RequirePackage{natmove}
\renewcommand{\bibfont}{\small}
% modifed from https://github.com/gbhutani/vancouver_authoryear_bibstyle/
\IfFileExists{vancouver-vfastcs.bst}
 %{\bibliographystyle{vancouver-vfastcs}}
  {\PackageWarning{elife}{vancouver-vfastcs.bst not found; falling back to IEEE bibliography style.}\bibliographystyle{ieeetr}}
% Make author in citation italic
\renewcommand{\NAT@nmfmt}[1]{{\bfseries\itshape\color{vfastcsMediumGrey} #1}}

% ...as well as the year
\xpatchcmd{\NAT@citex}
{\@citea\NAT@hyper@{\NAT@nmfmt{\NAT@nm}\NAT@date}}
{\@citea\NAT@hyper@{\NAT@nmfmt{\NAT@nm}\NAT@nmfmt{\NAT@date}}}
{}{\PackageWarning{vfastcs}{Failed to patch year format in citation}}

\xpatchcmd{\NAT@citex}
{\else\unskip\NAT@spacechar\NAT@hyper@{\NAT@date}}
{\else\unskip\NAT@spacechar\NAT@hyper@{\NAT@nmfmt{\NAT@date}}}
{}{\PackageWarning{vfastcs}{Failed to patch year format in citation}}

\xpatchcmd{\NAT@citex}
{\hyper@natlinkbreak{\NAT@aysep\NAT@spacechar}{\@citeb\@extra@b@citeb}\NAT@date}
{\hyper@natlinkbreak{\NAT@nmfmt{\NAT@aysep\NAT@spacechar}}{\@citeb\@extra@b@citeb}\NAT@nmfmt{\NAT@date}}
{}{\PackageWarning{vfastcs}{Failed to patch year format in citation}}

\xpatchcmd{\NAT@citex}
{\@citea\NAT@hyper@{\NAT@date}}
{\@citea\NAT@hyper@{\NAT@nmfmt{\NAT@date}}}
{}{\PackageWarning{vfastcs}{Failed to patch year format in citation}}

\xpatchcmd{\NAT@citex}
{{\@citeb\@extra@b@citeb}\NAT@date}
{{\@citeb\@extra@b@citeb}\NAT@nmfmt{\NAT@date}}
{}{\PackageWarning{vfastcs}{Failed to patch year format in citation}}
%% There, we're finally done with patching the year in citations.

%
% headers and footers
%

\RequirePackage{fancyhdr}  % custom headers/footers
\RequirePackage{lastpage}  % Number of pages in the document
\pagestyle{fancy}          % Enables the custom headers/footers
%% Next two lines unnecessary for vfastcs
% \addtolength{\headwidth}{\marginparsep}
% \addtolength{\headwidth}{\marginparwidth}

%% different document types listed here

\newif\ifdocumenttype
\documenttypefalse

\if@bestpractices
\documenttypetrue
\newcommand{\documenttype}{Best Practices Guide}
\else
 % nothing
\fi

\if@editorial
\documenttypetrue
\newcommand{\documenttype}{Editorial}
\else
% nothing
\fi

\if@tutorial
\documenttypetrue
\newcommand{\documenttype}{Tutorial}
\else
% nothing
\fi

\if@training
\documenttypetrue
\newcommand{\documenttype}{Training Article}
\else
% nothing
\fi

\if@review
\documenttypetrue
\newcommand{\documenttype}{Perpetual Review}
\else
% nothing
\fi

\if@software
\documenttypetrue
\newcommand{\documenttype}{VFAST Transactions on Software Engineering Volume 11, Issue 4, 2023}
\else
% nothing
\fi

\if@lessons
\documenttypetrue
\newcommand{\documenttype}{``Lessons Learned'' Document}
\else
% nothing
\fi

\fancyhf{}
\ifdocumenttype
\chead{%
\setlength{\fboxsep}{3pt}
\colorbox{vfastcsLightGray}{\begin{minipage}{\headwidth}\leftmargin\color{vfastcsBlack}  \documenttype\end{minipage}}%
}
\fi

% Publication information in document footer
% *ONLY INCLUDED IF "pubversion" CLASS OPTION IS INVOKED*
\def\@publishedDOI{}
\def\@publishedvolume{}
\def\@publishedyear{}
\def\@publishedarticlenum{}
\def\@publisheddatereceived{}
\def\@publisheddateaccepted{}
\def \DOIprefix{10.XXXX} %May be able to use this later
\newcommand{\pubDOI}[1]{%
  \appto{\@publishedDOI}{#1}{}{}
}
\newcommand{\pubvolume}[1]{%
  \appto{\@publishedvolume}{#1}{}{}
}
\newcommand{\pubissue}[1]{%
  \appto{\@publishedissue}{#1}{}{}
}
\newcommand{\pubyear}[1]{%
  \appto{\@publishedyear}{#1}{}{}
}
\newcommand{\articlenum}[1]{%
  \appto{\@publishedarticlenum}{#1}{}{}
}
\newcommand{\datereceived}[1]{%
  \appto{\@publisheddatereceived}{#1}{}{}
}
\newcommand{\dateaccepted}[1]{%
  \appto{\@publisheddateaccepted}{#1}{}{}
}

%--------------------------------------------------------
% Footers
% 1. Publication Version: put submission/acceptance dates in left footer and citation information in right footer
\if@pubversion
  \lfoot{\ifthenelse{\value{page}=1}
    {\small\color{vfastcsMediumGrey}Received: \@publisheddatereceived \\ Accepted: \@publisheddateaccepted}
    {~\\~}
  }%
  \rfoot{\small\color{vfastcsMediumGrey}\href{https://doi.org/\@publishedDOI}{https://doi.org/\@publishedDOI}\\
    {\it Living J. Comp. Mol. Sci.} \@publishedyear, \@publishedvolume\nobreak\hspace{.05em}(\@publishedissue), \@publishedarticlenum
  }%
\fi
% 2. Page Number in center of footer
%\cfoot{\small\color{white} \vspace{\baselineskip} \small\color{vfastcsMediumGrey} \thepage\space of\space\pageref{LastPage}}%
\preto{\footrule}{\color{vfastcsMediumGrey}}
\renewcommand{\headrulewidth}{0pt}% % No header rule
\renewcommand{\footrulewidth}{0.4pt}% % No footer rule
%----------------------------------------------------------

%
% section/subsection/paragraph set-up
% Updated for vfastcs
% \setcounter{secnumdepth}{0}
\RequirePackage[explicit]{titlesec}
\titleformat{\section}
  {\lARGE\bfseries\raggedright}
  {\thesection}{1em}{#1}[]

\titleformat{\subsection}
  {\large\bfseries\raggedright\color{vfastcsMediumGrey}}
  {\thesubsection}{1em}{#1}[]
\titleformat{\subsubsection}
  {\large\raggedright\color{vfastcsMediumGrey}}
  {\thesubsubsection}{1em}{#1}[]
\titleformat{\paragraph}
  {\large\raggedright\color{vfastcsMediumGrey}}
  {\theparagraph}{1em}{#1}[]
\titlespacing*{\section}{0pc}{1.5ex \@plus4pt \@minus3pt}{0pt}
\titlespacing*{\subsection}{0pc}{1ex \@plus3pt \@minus2pt}{0pt}
\titlespacing*{\subsubsection}{0pc}{2ex \@plus2 pt \@minus1.5pt}{0pt}
\titlespacing*{\paragraph}{0pc}{1.5ex \@plus2pt \@minus1pt}{0pt}

\RequirePackage{enumitem}
\setlist{noitemsep}

\RequirePackage{alphalph}
\newalphalph{\fnsymbolmult}[mult]{\@fnsymbol}{5}

\newcounter{authorfn}
\setcounter{authorfn}{1}
\newcommand{\authfn}[1]{%
  \fnsymbolmult{\numexpr\value{authorfn}+#1}%
}

\def\@correspondence{}
\def\@contribution{}
\def\@presentaddress{}
\def\@deceased{}
% Added blurb for vfastcs
\def\@blurb{}
\def\@orcidblock{}


\newcommand{\corr}[2]{%
  \ifx\empty\@correspondence\else\appto{\@correspondence}{; }{}{}\fi
  \appto{\@correspondence}{%
    \url{#1}%
    \ifx\empty#2\else\space(#2)\fi
  }{}{}%
}

\newcommand{\contrib}[2][]{
  \appto{\@contribution}{%
  \ifx\empty#1\else\textsuperscript{#1}\fi
  #2\\
  }{}{}
}

\newcommand{\presentadd}[2][]{
  \ifx\empty\@presentaddress\else\appto{\@presentaddress}{; }{}{}\fi
  \appto{\@presentaddress}{%
  \ifx\empty#1\else\textsuperscript{#1}\fi
  #2%
  }{}{}
}

\newcommand{\deceased}[1]{\def\@deceased{\textsuperscript{#1}Deceased}}

% Added for vfastcs
\newcommand{\blurb}[1]{\def\@blurb{#1}}

\newcommand{\orcid}[2]{%
  \ifx\empty\@orcidblock\else\appto{\@orcidblock}{\\}{}{}\fi
  \appto{\@orcidblock}{%
    #1:\space%
    \ifx\empty#2\else\href{https://orcid.org/#2}{#2} \fi
  }{}{}%
}



\reversemarginpar

%
% custom title page
%
\newcommand{\lARGE}{\fontsize{12}{16}\selectfont}
\renewcommand{\Authfont}{\bfseries\small\raggedright}
\renewcommand{\Affilfont}{\mdseries\small\raggedright}
\renewcommand{\Authands}{, }
\setlength{\affilsep}{16pt}
\renewcommand{\AB@affilsepx}{; \protect\Affilfont}

\newcommand{\doi}[1]{%
  \gdef\@doi{DOI: \href{https://doi.org/#1}{#1}}%
}


\newcommand{\themetadata}{%
    \textbf{*Correspondence author email address:}  \@correspondence\par
    \ifx\empty\@contribution\else
    \bigskip\@contribution\par\fi
    \ifx\empty\@presentaddress\else
    \par\fi
    \ifx\empty\@deceased\else\@deceased\par\fi
    \ifx\empty\@doi\else\@doi\par\fi
}

\patchcmd{\@author}{\AB@authlist\\[\affilsep]\AB@affillist}{\AB@authlist\\[\affilsep]
  %% Removed for vfastcs; will be placed after abstract in frontmatter
  % \marginpar{\raggedright\footnotesize\themetadata\par}
  \AB@affillist}{}{}

%% Added for vfastcs
\RequirePackage{environ}
\RequirePackage{textpos}

%% Abstract outside frontmatter will throw an error!
\RenewEnviron{abstract}{%
  \ClassError{vfastcs}
  {Nope nope nope, please put the abstract inside the frontmatter environment.}
  {Please put the abstract inside the frontmatter environment.}
}

\NewEnviron{frontmatter}{%
  %% Define abstract's behavior when placed in frontmatter
  \renewenvironment{abstract}{%
     \setlength{\parindent}{0pt} %\raggedright
     \raisebox{-16pt-\baselineskip}[0pt][0pt]{\makebox[0pt][r]{\parbox[t]{3cm}{%
       \raggedright\itshape\footnotesize\@blurb\par\medskip% 
     }\hspace*{1cm}}}%
     \textcolor{vfastcsMediumGrey}{\rule{\textwidth}{2pt}}
     \vskip16pt
     \textcolor{vfastcsBlack}{\large\bfseries\abstractname\space}
  }{%
     \vskip8pt
     \textcolor{vfastcsMediumGrey}{\rule{\textwidth}{2pt}}
     \vskip5pt
  }
  \twocolumn[%
    \protecting{%\begin{minipage}[b]{3cm}
    % \small\itshape
    % \raggedright\@blurb
    % \end{minipage}
    \hfill
    \begin{minipage}[b]{\textwidth-4cm}
    \BODY
    \themetadata%
    \end{minipage}}\vspace*{2\baselineskip}
  ]%
}
%%%%logosupportcode%%%
\renewcommand{\maketitle}{%
  \vskip36pt%
  \journallogo % Add the journal logo here
  {\color{vfastcsLightGray}\raggedright\bfseries\fontsize{17}{17}\selectfont \@title\par}%
  \vskip16pt
  {\@author\par}
  \vskip8pt
}

%%%%%
\renewcommand{\maketitle}{%
  \vskip36pt%
  {\color{vfastcsBlack}\raggedright\bfseries\fontsize{18}{18}\selectfont \@title\par}%
  \vskip16pt
  {\@author\par}
  \vskip8pt
  
  
}

\newcommand{\makeorcid}{%
  % \textbf{*For correspondence:\\}  \@correspondence\par
  % \textbf{ORCID:\\}  \@correspondence\par
  \textbf{ORCID:\\}  \@orcidblock\par
  
}

%% Insert a grey line to separate floats from main text
\newcommand{\topfigrule}{\vskip8pt\noindent{\rule{\linewidth}{1pt}}}
\newcommand{\botfigrule}{\noindent{\rule{\linewidth}{1pt}}\vskip8pt}

\RequirePackage{newfloat}
\RequirePackage{wrapfig}
\AtEndEnvironment{wrapfigure}{\vskip8pt\noindent{\rule{\hsize}{1pt}}}
% \RequirePackage[lflt]{floatflt}
% \AtEndEnvironment{floatingfigure}{\vskip8pt\noindent\textcolor{vfastcsMediumGrey}{\rule{\hsize}{2pt}}}

\DeclareFloatingEnvironment[placement=hbt,name=Box]{featurebox}
\captionsetup[featurebox]{font={Large,bf,color=vfastcsLightGray}}

\newcounter{featurefigure}
\newcounter{featuretable}
\AtBeginEnvironment{featurebox}{%
  \setcounter{featurefigure}{0}%
  \setcounter{featuretable}{0}%
  \newcommand{\featurefig}[1]{%
    \refstepcounter{featurefigure}%
    \vskip\smallskipamount%
    {\small\textbf{\color{vfastcsLightGray}Box \arabic{featurebox} Figure \arabic{featurefigure}.}\space #1\par}\medskip}
  \newcommand{\featuretable}[1]{%
    \refstepcounter{featuretable}%
    \vskip\smallskipamount%
    {\small\textbf{\color{vfastcsLightGray}Box \arabic{featurebox} Table \arabic{featuretable}.}\space #1\par}\medskip}

}
\apptocmd{\featurebox}{%
  \begin{mdframed}[linewidth=0pt,backgroundcolor=vfastcsLightBlue!10,fontcolor=vfastcsLightGray]
  \if@reqslineno\addtolength{\linenumbersep}{1em}\internallinenumbers\fi%
}{}{}
\pretocmd{\endfeaturebox}{\end{mdframed}}{}{}

%% Starred version for vfastcs two-column
\AtBeginEnvironment{featurebox*}{%
  \setcounter{featurefigure}{0}%
  \setcounter{featuretable}{0}%
  \newcommand{\featurefig}[1]{%
    \refstepcounter{featurefigure}%
    \vskip\smallskipamount%
    {\small\textbf{\color{vfastcsLightGray}Box \arabic{featurebox} Figure \arabic{featurefigure}.}\space #1\par}\medskip}
  \newcommand{\featuretable}[1]{%
    \refstepcounter{featuretable}%
    \vskip\smallskipamount%
    {\small\textbf{\color{vfastcsLightGray}Box \arabic{featurebox} Table \arabic{featuretable}.}\space #1\par}\medskip}
}
\expandafter\apptocmd\csname featurebox*\endcsname{%
  \begin{mdframed}[linewidth=0pt,backgroundcolor=vfastcsLightBlue!10,fontcolor=vfastcsLightGray]
  \if@reqslineno\addtolength{\linenumbersep}{1em}\internallinenumbers\fi%
}{}{}
\expandafter\pretocmd\csname endfeaturebox*\endcsname{\end{mdframed}}{}{}

%% Unnecessary for vfastcs
% \newenvironment{fullwidth}{%
%   \begin{adjustwidth}{-4.5cm}{}
% }{\end{adjustwidth}}

%% Provide support for pseudocode and algorithms
\RequirePackage{algorithm,algpseudocode}
\captionsetup[algorithm]{%
   labelfont={bf},font=small,labelsep=period,
   justification=raggedright,singlelinecheck=false}
\newcommand\fs@notopruled{\def\@fs@cfont{\bfseries}\let\@fs@capt\floatc@ruled
  \def\@fs@pre{}% \hrule height.8pt depth0pt \kern2pt}%
  \def\@fs@post{} %\kern2pt\hrule\relax}%
  \def\@fs@mid{\medskip\kern2pt\hrule\kern2pt}%
  \let\@fs@iftopcapt\iftrue}
\floatstyle{notopruled}
\restylefloat{algorithm}
\newcommand{\algorithmautorefname}{Algorithm}
\newcommand{\ALG}[1]{\autoref{alg:#1}}

%% Update some appendix sectional styles
\appto{\appendix}{%
  \@addtoreset{figure}{section}
  \@addtoreset{table}{section}
  \@addtoreset{featurebox}{section}
  \@addtoreset{algorithm}{section}
  % \numberwithin{figure}{section}
  % \numberwithin{table}{section}
  % \numberwithin{featurebox}{section}
  \titleformat{\section}
    {\LARGE\bfseries\color{vfastcsLightGray}}
    {\appendixname\ \thesection}{1em}{#1}[]

  \captionsetup*[figure]{name={Appendix \thesection\ Figure },font={color=vfastcsLightGray,small},skip=\smallskipamount}%

  \captionsetup*[table]{name={Appendix \thesection\ Table },font={color=vfastcsLightGray,small}}%
}

\newcounter{figsupp}
\setcounter{figsupp}{0}
\newcounter{data}
\setcounter{data}{0}
\def\supplist{}

\RequirePackage{newfile}
\newoutputstream{suppinfo}
\openoutputfile{\jobname.suppinfo}{suppinfo}


\AtBeginEnvironment{figure}{%
  \setcounter{figsupp}{0}
  \setcounter{data}{0}
  %% Updated 2017/06/30 to allow optional argument
  \newcommand{\figsupp}[3][]{%
    \refstepcounter{figsupp}%
    {%
    \ifstrequal{#1}{none}{}{%
      \small\textbf{Figure~\thefigure--Figure supplement \arabic{figsupp}.} \ifstrempty{#1}{#2}{#1}}\par}
    \addtostream{suppinfo}{%
      \noindent\protect\begin{minipage}{\linewidth}
      \protect #3\noexpand\par
      \textbf{Figure \thefigure--Figure supplement \arabic{figsupp}.} #2\noexpand\par
      \vskip8pt
      \protect\end{minipage}
      \vskip16pt
    }
  }
  \newcommand{\figdata}[1]{%
    \refstepcounter{data}
    {\small\textbf{Figure~\thefigure--source data \arabic{data}.} #1}\par
  }
}

%% Added for vfastcs (two columns)
\AtBeginEnvironment{figure*}{%
  \setcounter{figsupp}{0}
  \setcounter{data}{0}
  %% Updated 2017/06/30 to allow optional argument
  \newcommand{\figsupp}[3][]{%
    \refstepcounter{figsupp}%
    {%
    \ifstrequal{#1}{none}{}{%
      \small\textbf{Figure~\thefigure--Figure supplement \arabic{figsupp}.} \ifstrempty{#1}{#2}{#1}}\par}
    \addtostream{suppinfo}{%
      \noindent\protect\begin{minipage}{\linewidth}
      \protect #3\noexpand\par
      \textbf{Figure \thefigure--Figure supplement \arabic{figsupp}.} #2\noexpand\par
      \vskip8pt
      \protect\end{minipage}
      \vskip16pt
    }
  }
  \newcommand{\figdata}[1]{%
    \refstepcounter{data}
    {\small\textbf{Figure~\thefigure--source data \arabic{data}.} #1}\par
  }
}

\AtBeginEnvironment{table}{%
  \setcounter{data}{0}
  \newcommand{\tabledata}[1]{%
    \refstepcounter{data}
    {\small\textbf{Table~\thetable--source data \arabic{data}.} #1}\par
  }
}

%% Added for vfastcs (twocolumns)
\AtBeginEnvironment{table*}{%
  \setcounter{data}{0}
  \newcommand{\tabledata}[1]{%
    \refstepcounter{data}
    {\small\textbf{Table~\thetable--source data \arabic{data}.} #1}\par
  }
}

%% Checklists as floats
\RequirePackage{fontawesome}
\DeclareFloatingEnvironment[placement=hbtp,name=Checklists]{Checklists}
\newcounter{checklist}
\AtBeginEnvironment{Checklists}{%
  \setcounter{checklist}{0}
  \mdfsetup{skipabove=0pt,skipbelow=0pt,
    frametitleaboveskip=12pt,innerbottommargin=12pt,
    hidealllines=true,
    frametitlefont=\Large\bfseries\color{vfastcsLightBlue}}
}{}{}

\AtBeginEnvironment{Checklists*}{%
  \setcounter{checklist}{0}
  \mdfsetup{skipabove=0pt,skipbelow=0pt,
    frametitleaboveskip=12pt,innerbottommargin=12pt,
    hidealllines=true,
    frametitlefont=\Large\bfseries\color{vfastcsLightBlue}}
}{}{}

  \newenvironment{checklist}[1]{%
    \stepcounter{checklist}
    \ifnumodd{\thechecklist}
      {\def\cl@bgcolor{gray!12}}
      {\def\cl@bgcolor{gray!25}}
    \begin{mdframed}[
      frametitle=\MakeUppercase{#1},
      backgroundcolor=\cl@bgcolor]
      \setlist[itemize]{label=$\Box$,leftmargin=*}
  }{\end{mdframed}}

\AtEndDocument{%
  \closeoutputstream{suppinfo}
%  \pagestyle{empty}
  \renewcommand{\footrule}{}
  \rfoot{}
  \input{\jobname.suppinfo}
}



\RequirePackage[colorlinks=true,allcolors=vfastcsBlack,citecolor=vfastcsLightBlue,linkcolor=vfastcsMediumGrey,urlcolor=vfastcsLightBlue]{hyperref}
\urlstyle{sf}

% Other desired commands
\renewcommand{\equationautorefname}{Eq.}
\newcommand{\FIG}[1]{\autoref{fig:#1}}
\newcommand{\TABLE}[1]{\autoref{tab:#1}}
\newcommand{\EQ}[1]{\autoref{eq:#1}}
\newcommand{\BOX}[1]{\autoref{box:#1}}
\let\oldautoref\autoref
\renewcommand{\autoref}[1]{\emph{\textbf{\oldautoref{#1}}}}

\endinput
